package com.ruoyi.ems.mapper;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.ems.domain.OpAlarm;

/**
 * 能源设施告警Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-26
 */
public interface OpAlarmMapper {
    /**
     * 查询能源设施告警
     *
     * @param id 能源设施告警主键
     * @return 能源设施告警
     */
    OpAlarm selectAdmOpAlarmById(Long id);

    /**
     * 查询能源设施告警列表
     *
     * @param admOpAlarm 能源设施告警
     * @return 能源设施告警集合
     */
    List<OpAlarm> selectAdmOpAlarmList(OpAlarm admOpAlarm);

    /**
     * 新增能源设施告警
     *
     * @param admOpAlarm 能源设施告警
     * @return 结果
     */
    int insertAdmOpAlarm(OpAlarm admOpAlarm);

    /**
     * 修改能源设施告警
     *
     * @param admOpAlarm 能源设施告警
     * @return 结果
     */
    int updateAdmOpAlarm(OpAlarm admOpAlarm);

    /**
     * 删除能源设施告警
     *
     * @param id 能源设施告警主键
     * @return 结果
     */
    int deleteAdmOpAlarmById(Long id);

    /**
     * 批量删除能源设施告警
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAdmOpAlarmByIds(Long[] ids);

    List<Map<String, Object>> qryAlarmTypeIndex(@Param("areaCode") String areaCode,
        @Param("startTime") String startTime, @Param("endTime") String endTime);

    List<Map<String, Object>> qryAlarmTypeIndexByDate(OpAlarm admOpAlarm);
    List<Map<String, Object>> qryAlarmTypeIndexDay(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    List<Map<String, Object>> qryAlarmTypeIndexMonth(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    List<Map<String, Object>> qryAlarmTypeIndexYear(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    List<Map<String, Object>> qrySubSysIndexDay(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    List<Map<String, Object>> qrySubSysIndexMonth(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    List<Map<String, Object>> qrySubSysIndexYear(@Param("alarmDate") String alarmDate,
        @Param("areaCode") String areaCode);

    Map<String, Object> cntHandledAlarmByDate(OpAlarm admOpAlarm);

}
